# -*- coding: utf-8 -*-
# Generated by Django 1.11.5 on 2017-09-21 21:51
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_stripe', '0013_stripesubscription_at_period_end'),
    ]

    operations = [
        migrations.AddField(
            model_name='stripecharge',
            name='charge_attempt_failed',
            field=models.BooleanField(default=False),
        ),
    ]
