# -*- coding: utf-8 -*-
# Generated by Django 1.11.5 on 2017-09-25 12:38
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_stripe', '0014_stripecharge_charge_attempt_failed'),
    ]

    operations = [
        migrations.AlterField(
            model_name='stripesubscriptionplan',
            name='amount',
            field=models.BigIntegerField(help_text='In cents. More: https://stripe.com/docs/api#create_plan-amount'),
        ),
    ]
