# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-09-07 16:01
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_stripe', '0010_auto_20170822_1004'),
    ]

    operations = [
        migrations.AddField(
            model_name='stripewebhook',
            name='parse_error',
            field=models.TextField(blank=True),
        ),
    ]
